@@ -1,5 +1,5 @@
 /* GNU gettext - internationalization aids
-   Copyright (C) 1995-1998, 2000-2010, 2012, 2015 Free Software
+   Copyright (C) 1995-1998, 2000-2010, 2012, 2014-2016, 2018-2020 Free Software
    Foundation, Inc.
    This file was written by Peter Miller <millerp@canb.auug.org.au>
 
@@ -14,7 +14,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -28,6 +28,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <locale.h>
+#ifdef _OPENMP
+# include <omp.h>
+#endif
+
+#include <textstyle.h>
 
 #include "closeout.h"
 #include "dir-list.h"
@@ -45,7 +50,6 @@
 #include "write-po.h"
 #include "write-properties.h"
 #include "write-stringtable.h"
-#include "color.h"
 #include "format.h"
 #include "xalloc.h"
 #include "xmalloca.h"
@@ -85,6 +89,14 @@ static int force_po;
 /* Apply the .pot file to each of the domains in the PO file.  */
 static bool multi_domain_mode = false;
 
+/* Produce output for msgfmt, not for a translator.
+   msgfmt ignores
+     - untranslated messages,
+     - fuzzy messages, except the header entry,
+     - obsolete messages.
+   Therefore output for msgfmt does not need to include such messages.  */
+static bool for_msgfmt = false;
+
 /* Determines whether to use fuzzy matching.  */
 static bool use_fuzzy_matching = true;
 
@@ -111,9 +123,10 @@ static const struct option long_options[] =
   { "add-location", optional_argument, NULL, 'n' },
   { "backup", required_argument, NULL, CHAR_MAX + 1 },
   { "color", optional_argument, NULL, CHAR_MAX + 9 },
-  { "compendium", required_argument, NULL, 'C', },
+  { "compendium", required_argument, NULL, 'C' },
   { "directory", required_argument, NULL, 'D' },
   { "escape", no_argument, NULL, 'E' },
+  { "for-msgfmt", no_argument, NULL, CHAR_MAX + 12 },
   { "force-po", no_argument, &force_po, 1 },
   { "help", no_argument, NULL, 'h' },
   { "indent", no_argument, NULL, 'i' },
@@ -139,7 +152,7 @@ static const struct option long_options[] =
   { "update", no_argument, NULL, 'U' },
   { "verbose", no_argument, NULL, 'v' },
   { "version", no_argument, NULL, 'V' },
-  { "width", required_argument, NULL, 'w', },
+  { "width", required_argument, NULL, 'w' },
   { NULL, 0, NULL, 0 }
 };
 
@@ -188,10 +201,8 @@ main (int argc, char **argv)
   quiet = false;
   gram_max_allowed_errors = UINT_MAX;
 
-#ifdef HAVE_SETLOCALE
   /* Set locale via LC_ALL.  */
   setlocale (LC_ALL, "");
-#endif
 
   /* Set the text message domain.  */
   bindtextdomain (PACKAGE, relocate (LOCALEDIR));
@@ -344,6 +355,10 @@ main (int argc, char **argv)
         message_print_style_filepos (filepos_comment_none);
         break;
 
+      case CHAR_MAX + 12: /* --for-msgfmt */
+        for_msgfmt = true;
+        break;
+
       default:
         usage (EXIT_FAILURE);
         break;
@@ -355,11 +370,11 @@ main (int argc, char **argv)
       printf ("%s (GNU %s) %s\n", basename (program_name), PACKAGE, VERSION);
       /* xgettext: no-wrap */
       printf (_("Copyright (C) %s Free Software Foundation, Inc.\n\
-License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+License GPLv3+: GNU GPL version 3 or later <%s>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n\
 "),
-              "1995-1998, 2000-2010");
+              "1995-2020", "https://gnu.org/licenses/gpl.html");
       printf (_("Written by %s.\n"), proper_name ("Peter Miller"));
       exit (EXIT_SUCCESS);
     }
@@ -388,6 +403,11 @@ There is NO WARRANTY, to the extent permitted by law.\n\
           error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
                  "--update", "--output-file");
         }
+      if (for_msgfmt)
+        {
+          error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
+                 "--update", "--for-msgfmt");
+        }
       if (color != NULL)
         {
           error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
@@ -426,6 +446,27 @@ There is NO WARRANTY, to the extent permitted by law.\n\
   if (update_mode && input_syntax == &input_format_stringtable)
     output_syntax = &output_format_stringtable;
 
+  if (for_msgfmt)
+    {
+      /* With --for-msgfmt, no fuzzy matching.  */
+      use_fuzzy_matching = false;
+
+      /* With --for-msgfmt, merging is fast, therefore no need for a progress
+         indicator.  */
+      quiet = true;
+
+      /* With --for-msgfmt, no need for comments.  */
+      message_print_style_comment (false);
+
+      /* With --for-msgfmt, no need for source location lines.  */
+      message_print_style_filepos (filepos_comment_none);
+    }
+
+  /* Initialize OpenMP.  */
+  #ifdef _OPENMP
+  openmp_init ();
+  #endif
+
   /* Merge the two files.  */
   result = merge (argv[optind], argv[optind + 1], input_syntax, &def);
 
@@ -479,8 +520,8 @@ There is NO WARRANTY, to the extent permitted by law.\n\
   else
     {
       /* Write the merged message list out.  */
-      msgdomain_list_print (result, output_file, output_syntax, force_po,
-                            false);
+      msgdomain_list_print (result, output_file, output_syntax,
+                            for_msgfmt || force_po, false);
     }
 
   exit (EXIT_SUCCESS);
@@ -567,6 +608,9 @@ Operation modifiers:\n"));
       printf (_("\
   -m, --multi-domain          apply ref.pot to each of the domains in def.po\n"));
       printf (_("\
+      --for-msgfmt            produce output for '%s', not for a translator\n"),
+              "msgfmt");
+      printf (_("\
   -N, --no-fuzzy-matching     do not use fuzzy matching\n"));
       printf (_("\
       --previous              keep previous msgids of translated messages\n"));
@@ -628,12 +672,16 @@ Informative output:\n"));
       printf (_("\
   -q, --quiet, --silent       suppress progress indicators\n"));
       printf ("\n");
-      /* TRANSLATORS: The placeholder indicates the bug-reporting address
-         for this package.  Please add _another line_ saying
+      /* TRANSLATORS: The first placeholder is the web address of the Savannah
+         project of this package.  The second placeholder is the bug-reporting
+         email address for this package.  Please add _another line_ saying
          "Report translation bugs to <...>\n" with the address for translation
          bugs (typically your translation team's web or email address).  */
-      fputs (_("Report bugs to <bug-gnu-gettext@gnu.org>.\n"),
-             stdout);
+      printf(_("\
+Report bugs in the bug tracker at <%s>\n\
+or by email to <%s>.\n"),
+             "https://savannah.gnu.org/projects/gettext",
+             "bug-gettext@gnu.org");
     }
 
   exit (status);
@@ -1500,11 +1548,19 @@ match_domain (const char *fn1, const char *fn2,
           message_ty *mp =
             message_merge (defmsg, refmsg, false, &distribution);
 
-          message_list_append (resultmlp, mp);
+          /* When producing output for msgfmt, omit messages that are
+             untranslated or fuzzy (except the header entry).  */
+          if (!(for_msgfmt
+                && (mp->msgstr[0] == '\0' /* untranslated? */
+                    || (mp->is_fuzzy && !is_header (mp))))) /* fuzzy? */
+            {
+              message_list_append (resultmlp, mp);
+
+              /* Remember that this message has been used, when we scan
+                 later to see if anything was omitted.  */
+              defmsg->used = 1;
+            }
 
-          /* Remember that this message has been used, when we scan
-             later to see if anything was omitted.  */
-          defmsg->used = 1;
           stats->merged++;
         }
       else if (!is_header (refmsg))
@@ -1520,11 +1576,11 @@ match_domain (const char *fn1, const char *fn2,
 
               if (verbosity_level > 1)
                 {
-                  po_gram_error_at_line (&refmsg->pos, _("\
-this message is used but not defined..."));
+                  po_gram_error_at_line (&refmsg->pos,
+                                         _("this message is used but not defined..."));
                   error_message_count--;
-                  po_gram_error_at_line (&defmsg->pos, _("\
-...but this definition is similar"));
+                  po_gram_error_at_line (&defmsg->pos,
+                                         _("...but this definition is similar"));
                 }
 
               /* Merge the reference with the definition: take the #. and
@@ -1538,6 +1594,7 @@ this message is used but not defined..."));
               /* Remember that this message has been used, when we scan
                  later to see if anything was omitted.  */
               defmsg->used = 1;
+
               stats->fuzzied++;
               if (!quiet && verbosity_level <= 1)
                 /* Always print a dot if we handled a fuzzy match.  */
@@ -1551,32 +1608,37 @@ this message is used but not defined..."));
               const char *pend;
 
               if (verbosity_level > 1)
-                po_gram_error_at_line (&refmsg->pos, _("\
-this message is used but not defined in %s"), fn1);
+                po_gram_error_at_line (&refmsg->pos,
+                                       _("this message is used but not defined in %s"),
+                                       fn1);
 
               mp = message_copy (refmsg);
 
-              if (mp->msgid_plural != NULL)
+              /* Test if mp is untranslated.  (It most likely is.)  */
+              is_untranslated = true;
+              for (p = mp->msgstr, pend = p + mp->msgstr_len; p < pend; p++)
+                if (*p != '\0')
+                  {
+                    is_untranslated = false;
+                    break;
+                  }
+
+              if (mp->msgid_plural != NULL && is_untranslated)
                 {
-                  /* Test if mp is untranslated.  (It most likely is.)  */
-                  is_untranslated = true;
-                  for (p = mp->msgstr, pend = p + mp->msgstr_len; p < pend; p++)
-                    if (*p != '\0')
-                      {
-                        is_untranslated = false;
-                        break;
-                      }
-                  if (is_untranslated)
-                    {
-                      /* Change mp->msgstr_len consecutive empty strings into
-                         nplurals consecutive empty strings.  */
-                      if (nplurals > mp->msgstr_len)
-                        mp->msgstr = untranslated_plural_msgstr;
-                      mp->msgstr_len = nplurals;
-                    }
+                  /* Change mp->msgstr_len consecutive empty strings into
+                     nplurals consecutive empty strings.  */
+                  if (nplurals > mp->msgstr_len)
+                    mp->msgstr = untranslated_plural_msgstr;
+                  mp->msgstr_len = nplurals;
+                }
+
+              /* When producing output for msgfmt, omit messages that are
+                 untranslated or fuzzy (except the header entry).  */
+              if (!(for_msgfmt && (is_untranslated || mp->is_fuzzy)))
+                {
+                  message_list_append (resultmlp, mp);
                 }
 
-              message_list_append (resultmlp, mp);
               stats->missing++;
             }
         }
@@ -1623,10 +1685,8 @@ this message is used but not defined in %s"), fn1);
                 unsigned long i;
 
                 if (verbosity_level > 1)
-                  {
-                    po_gram_error_at_line (&mp->pos, _("\
-this message should define plural forms"));
-                  }
+                  po_gram_error_at_line (&mp->pos,
+                                         _("this message should define plural forms"));
 
                 new_msgstr_len = nplurals * mp->msgstr_len;
                 new_msgstr = XNMALLOC (new_msgstr_len, char);
@@ -1646,10 +1706,8 @@ this message should define plural forms"));
                    Use only the first among the plural forms.  */
 
                 if (verbosity_level > 1)
-                  {
-                    po_gram_error_at_line (&mp->pos, _("\
-this message should not define plural forms"));
-                  }
+                  po_gram_error_at_line (&mp->pos,
+                                         _("this message should not define plural forms"));
 
                 mp->msgstr_len = strlen (mp->msgstr) + 1;
                 mp->is_fuzzy = true;
@@ -1998,48 +2056,51 @@ merge (const char *fn1, const char *fn2, catalog_input_format_ty input_syntax,
 
   definitions_destroy (&definitions);
 
-  /* Look for messages in the definition file, which are not present
-     in the reference file, indicating messages which defined but not
-     used in the program.  Don't scan the compendium(s).  */
-  for (k = 0; k < def->nitems; ++k)
+  if (!for_msgfmt)
     {
-      const char *domain = def->item[k]->domain;
-      message_list_ty *defmlp = def->item[k]->messages;
-
-      for (j = 0; j < defmlp->nitems; j++)
+      /* Look for messages in the definition file, which are not present
+         in the reference file, indicating messages which defined but not
+         used in the program.  Don't scan the compendium(s).  */
+      for (k = 0; k < def->nitems; ++k)
         {
-          message_ty *defmsg = defmlp->item[j];
+          const char *domain = def->item[k]->domain;
+          message_list_ty *defmlp = def->item[k]->messages;
 
-          if (!defmsg->used)
+          for (j = 0; j < defmlp->nitems; j++)
             {
-              /* Remember the old translation although it is not used anymore.
-                 But we mark it as obsolete.  */
-              message_ty *mp;
+              message_ty *defmsg = defmlp->item[j];
 
-              mp = message_copy (defmsg);
-              /* Clear the extracted comments.  */
-              if (mp->comment_dot != NULL)
+              if (!defmsg->used)
                 {
-                  string_list_free (mp->comment_dot);
-                  mp->comment_dot = NULL;
-                }
-              /* Clear the file position comments.  */
-              if (mp->filepos != NULL)
-                {
-                  size_t i;
+                  /* Remember the old translation although it is not used anymore.
+                     But we mark it as obsolete.  */
+                  message_ty *mp;
 
-                  for (i = 0; i < mp->filepos_count; i++)
-                    free ((char *) mp->filepos[i].file_name);
-                  mp->filepos_count = 0;
-                  free (mp->filepos);
-                  mp->filepos = NULL;
-                }
-              /* Mark as obsolete.   */
-              mp->obsolete = true;
+                  mp = message_copy (defmsg);
+                  /* Clear the extracted comments.  */
+                  if (mp->comment_dot != NULL)
+                    {
+                      string_list_free (mp->comment_dot);
+                      mp->comment_dot = NULL;
+                    }
+                  /* Clear the file position comments.  */
+                  if (mp->filepos != NULL)
+                    {
+                      size_t i;
 
-              message_list_append (msgdomain_list_sublist (result, domain, true),
-                                   mp);
-              stats.obsolete++;
+                      for (i = 0; i < mp->filepos_count; i++)
+                        free ((char *) mp->filepos[i].file_name);
+                      mp->filepos_count = 0;
+                      free (mp->filepos);
+                      mp->filepos = NULL;
+                    }
+                  /* Mark as obsolete.   */
+                  mp->obsolete = true;
+
+                  message_list_append (msgdomain_list_sublist (result, domain, true),
+                                       mp);
+                  stats.obsolete++;
+                }
             }
         }
     }
